<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Tray</source>
        <translation>Systemabschnitt der Kontrolleiste</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Blinking Envelope</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Static Envelope</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Animated Envelope</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start minimized</source>
        <translation>Minimiert starten</translation>
    </message>
    <message>
        <source>Show tooltip over tray icon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tray icon indicating new message</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DockingMenuHandler</name>
    <message>
        <source>&amp;Restore</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Silent mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>